summaryrefslogtreecommitdiffstats
path: root/backends
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2019-10-26 08:29:37 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2019-10-26 08:29:53 +0000
commitd608b19e0d3b3f4d84fcfcdd72bb7e64c86b6f01 (patch)
tree8c283d1c81d718e64d87d9a2d1132c89f3915939 /backends
parentReleasing debian version 1.18.0-1. (diff)
downloadnetdata-d608b19e0d3b3f4d84fcfcdd72bb7e64c86b6f01.tar.xz
netdata-d608b19e0d3b3f4d84fcfcdd72bb7e64c86b6f01.zip
Merging upstream version 1.18.1.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'backends')
-rw-r--r--backends/prometheus/backend_prometheus.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/backends/prometheus/backend_prometheus.c b/backends/prometheus/backend_prometheus.c
index 67342ea7a..03323ac54 100644
--- a/backends/prometheus/backend_prometheus.c
+++ b/backends/prometheus/backend_prometheus.c
@@ -780,7 +780,7 @@ int process_prometheus_remote_write_response(BUFFER *b) {
const char *s = buffer_tostring(b);
int len = buffer_strlen(b);
// do nothing with HTTP response 200
while(!isspace(*s) && len) {
s++;
@@ -789,7 +789,7 @@ int process_prometheus_remote_write_response(BUFFER *b) {
s++;
len--;
- if(likely(len > 4 && !strncmp(s, "200 ", 4)))
+ if(likely(len > 4 && (!strncmp(s, "200 ", 4) || !strncmp(s, "204 ", 4))))
return 0;
else
return discard_response(b, "prometheus remote write");
@@ -780,7 +780,7 @@ int process_prometheus_remote_write_response(BUFFER *b) {
const char *s = buffer_tostring(b);
int len = buffer_strlen(b);
- // do nothing with HTTP response 200
+ // do nothing with HTTP responses 200 or 204
while(!isspace(*s) && len) {
s++;